@@ -174,9 +174,10 @@ class BaseResource(MethodView):
 
     def _get_json_payload(self, dct):
         def mydefault(obj):
-            if isinstance(obj, ObjectId):
-                return str(obj)
-            return json_util.default
+            d = json_util.default(obj)
+            if isinstance(d, dict) and '$oid' in d:
+                return d['$oid']
+            return d
 
         if self.payload_mongo_format:
             return json_util.dumps(dct)
